@@ -124,9 +124,9 @@ public final class standard_zh_CN extends java.util.ListResourceBundle {
             { "doclet.help.class_interface.intro", "\u6BCF\u4E2A\u7C7B, \u63A5\u53E3, \u5D4C\u5957\u7C7B\u548C\u5D4C\u5957\u63A5\u53E3\u90FD\u6709\u5404\u81EA\u7684\u9875\u9762\u3002\u5176\u4E2D\u6BCF\u4E2A\u9875\u9762\u90FD\u7531\u4E09\u90E8\u5206 (\u7C7B/\u63A5\u53E3\u8BF4\u660E, \u6982\u8981\u8868, \u4EE5\u53CA\u8BE6\u7EC6\u7684\u6210\u5458\u8BF4\u660E) \u7EC4\u6210:" },
             { "doclet.help.class_interface.subclasses", "\u76F4\u63A5\u5B50\u7C7B" },
             { "doclet.help.class_interface.subinterfaces", "\u6240\u6709\u5DF2\u77E5\u5B50\u63A5\u53E3" },
-            { "doclet.help.class_interface.summary", "\u6BCF\u4E2A\u6982\u8981\u6761\u76EE\u90FD\u5305\u542B\u8BE5\u9879\u76EE\u7684\u8BE6\u7EC6\u8BF4\u660E\u7684\u7B2C\u4E00\u53E5\u3002\u6982\u8981\u6761\u76EE\u6309\u5B57\u6BCD\u987A\u5E8F\u6392\u5217, \u800C\u8BE6\u7EC6\u8BF4\u660E\u5219\u6309\u5176\u5728\u6E90\u4EE3\u7801\u4E2D\u51FA\u73B0\u7684\u987A\u5E8F\u6392\u5217\u3002\u8FD9\u6837\u4FDD\u6301\u4E86\u7A0B\u5E8F\u5458\u6240\u5EFA\u7ACB\u7684\u903B\u8F91\u5206\u7EC4\u3002" },
+            { "doclet.help.class_interface.summary", "\u6982\u8981\u6761\u76EE\u6309\u5B57\u6BCD\u987A\u5E8F\u6392\u5217\uFF0C\u800C\u8BE6\u7EC6\u8BF4\u660E\u5219\u6309\u5176\u5728\u6E90\u4EE3\u7801\u4E2D\u51FA\u73B0\u7684\u987A\u5E8F\u6392\u5217\u3002\u8FD9\u6709\u52A9\u4E8E\u4FDD\u6301\u7A0B\u5E8F\u5458\u6240\u5EFA\u7ACB\u7684\u903B\u8F91\u5206\u7EC4\u3002" },
             { "doclet.help.constants.body", "{0}\u9875\u9762\u5217\u51FA\u4E86\u9759\u6001\u6700\u7EC8\u5B57\u6BB5\u53CA\u5176\u503C\u3002" },
-            { "doclet.help.deprecated.body", "{0} \u9875\u9762\u5217\u51FA\u4E86\u6240\u6709\u5DF2\u8FC7\u65F6\u7684 API\u3002\u4E00\u822C\u7531\u4E8E\u8FDB\u884C\u4E86\u6539\u8FDB\u5E76\u4E14\u901A\u5E38\u63D0\u4F9B\u4E86\u66FF\u4EE3\u7684 API, \u6240\u4EE5\u5EFA\u8BAE\u4E0D\u8981\u4F7F\u7528\u5DF2\u8FC7\u65F6\u7684 API\u3002\u5728\u5C06\u6765\u7684\u5B9E\u73B0\u8FC7\u7A0B\u4E2D, \u53EF\u80FD\u4F1A\u5220\u9664\u5DF2\u8FC7\u65F6\u7684 API\u3002" },
+            { "doclet.help.deprecated.body", "{0} \u9875\u9762\u5217\u51FA\u4E86\u6240\u6709\u5DF2\u8FC7\u65F6\u7684 API\u3002\u901A\u5E38\uFF0C\u7531\u4E8E\u5DF2\u8FC7\u65F6\u7684 API \u5B58\u5728\u7F3A\u70B9\u5E76\u4E14\u5DF2\u63D0\u4F9B\u66FF\u4EE3 API\uFF0C\u4E0D\u5EFA\u8BAE\u4F7F\u7528\u5DF2\u8FC7\u65F6\u7684 API\u3002\u5728\u5C06\u6765\u7684\u5B9E\u65BD\u4E2D\uFF0C\u53EF\u80FD\u4F1A\u5220\u9664\u5DF2\u8FC7\u65F6\u7684 API\u3002" },
             { "doclet.help.enum.declaration", "\u679A\u4E3E\u58F0\u660E" },
             { "doclet.help.enum.definition", "\u679A\u4E3E\u8BF4\u660E" },
             { "doclet.help.enum.intro", "\u6BCF\u4E2A\u679A\u4E3E\u90FD\u6709\u5404\u81EA\u7684\u9875\u9762, \u5176\u4E2D\u5305\u542B\u4EE5\u4E0B\u90E8\u5206:" },
@@ -135,7 +135,7 @@ public final class standard_zh_CN extends java.util.ListResourceBundle {
             { "doclet.help.index.head", "\u7D22\u5F15" },
             { "doclet.help.intro", "\u6B64 API (\u5E94\u7528\u7A0B\u5E8F\u7F16\u7A0B\u63A5\u53E3) \u6587\u6863\u5305\u542B\u5BF9\u5E94\u4E8E\u5BFC\u822A\u680F\u4E2D\u7684\u9879\u76EE\u7684\u9875\u9762, \u5982\u4E0B\u6240\u8FF0\u3002" },
             { "doclet.help.main_heading", "\u6B64 API \u6587\u6863\u7684\u7EC4\u7EC7\u65B9\u5F0F" },
-            { "doclet.help.module.intro", "\u6BCF\u4E2A\u6A21\u5757\u90FD\u6709\u4E00\u9875\uFF0C\u5176\u4E2D\u5305\u542B\u5B83\u7684\u7A0B\u5E8F\u5305\u3001\u4E0E\u5176\u4ED6\u6A21\u5757\u7684\u4F9D\u8D56\u5173\u7CFB\u548C\u670D\u52A1\u7684\u5217\u8868\u4EE5\u53CA\u5404\u4E2A\u6A21\u5757\u7684\u6982\u8981\u3002\u8FD9\u4E9B\u9875\u53EF\u4EE5\u5305\u542B\u4E09\u4E2A\u7C7B\u522B\uFF1A" },
+            { "doclet.help.module.intro", "\u6BCF\u4E2A\u6A21\u5757\u90FD\u6709\u4E00\u9875\uFF0C\u5176\u4E2D\u5305\u542B\u5B83\u7684\u7A0B\u5E8F\u5305\u3001\u4E0E\u5176\u4ED6\u6A21\u5757\u7684\u4F9D\u8D56\u5173\u7CFB\u548C\u670D\u52A1\u7684\u5217\u8868\u4EE5\u53CA\u6A21\u5757\u6982\u8981\u3002\u8FD9\u4E9B\u9875\u53EF\u4EE5\u5305\u542B\u4E09\u4E2A\u7C7B\u522B\uFF1A" },
             { "doclet.help.overview.modules.body", "{0} \u9875\u662F\u6B64 API \u6587\u6863\u7684\u9996\u9875\uFF0C\u63D0\u4F9B\u4E86\u6240\u6709\u6A21\u5757\u7684\u5217\u8868\u53CA\u5176\u6982\u8981\u3002\u6B64\u9875\u4E5F\u53EF\u80FD\u5305\u542B\u8FD9\u4E9B\u6A21\u5757\u7684\u603B\u4F53\u8BF4\u660E\u3002" },
             { "doclet.help.overview.packages.body", "{0} \u9875\u9762\u662F\u6B64 API \u6587\u6863\u7684\u9996\u9875, \u63D0\u4F9B\u4E86\u6240\u6709\u7A0B\u5E8F\u5305\u7684\u5217\u8868\u53CA\u5176\u6982\u8981\u3002\u6B64\u9875\u9762\u4E5F\u53EF\u80FD\u5305\u542B\u8FD9\u4E9B\u7A0B\u5E8F\u5305\u7684\u603B\u4F53\u8BF4\u660E\u3002" },
             { "doclet.help.package.intro", "\u6BCF\u4E2A\u7A0B\u5E8F\u5305\u90FD\u6709\u4E00\u9875\uFF0C\u5176\u4E2D\u5305\u542B\u5B83\u7684\u7C7B\u548C\u63A5\u53E3\u7684\u5217\u8868\u53CA\u5176\u6982\u8981\u3002\u8FD9\u4E9B\u9875\u53EF\u4EE5\u5305\u542B\u516D\u4E2A\u7C7B\u522B\uFF1A" },
@@ -145,7 +145,7 @@ public final class standard_zh_CN extends java.util.ListResourceBundle {
             { "doclet.help.search.refer", "\u6709\u5173\u641C\u7D22\u529F\u80FD\u7684\u5B8C\u6574\u8BF4\u660E\uFF0C\u8BF7\u53C2\u9605 {0}\u3002" },
             { "doclet.help.search.spec.title", "Javadoc \u641C\u7D22\u89C4\u8303" },
             { "doclet.help.search.spec.url", "https://docs.oracle.com/en/java/javase/{0}/docs/specs/javadoc/javadoc-search-spec.html" },
-            { "doclet.help.serial_form.body", "\u6BCF\u4E2A\u53EF\u5E8F\u5217\u5316\u6216\u53EF\u5916\u90E8\u5316\u7684\u7C7B\u90FD\u6709\u5176\u5E8F\u5217\u5316\u5B57\u6BB5\u548C\u65B9\u6CD5\u7684\u8BF4\u660E\u3002\u6B64\u4FE1\u606F\u5BF9\u91CD\u65B0\u5B9E\u73B0\u8005\u6709\u7528, \u800C\u5BF9\u4F7F\u7528 API \u7684\u5F00\u53D1\u8005\u5219\u6CA1\u6709\u4EC0\u4E48\u7528\u5904\u3002\u5C3D\u7BA1\u5BFC\u822A\u680F\u4E2D\u6CA1\u6709\u94FE\u63A5, \u4F46\u60A8\u53EF\u4EE5\u901A\u8FC7\u4E0B\u5217\u65B9\u5F0F\u83B7\u53D6\u6B64\u4FE1\u606F: \u8F6C\u81F3\u4EFB\u4F55\u5E8F\u5217\u5316\u7C7B, \u7136\u540E\u5355\u51FB\u7C7B\u8BF4\u660E\u7684 \"\u53E6\u8BF7\u53C2\u9605\" \u90E8\u5206\u4E2D\u7684 \"\u5E8F\u5217\u5316\u8868\u683C\"\u3002" },
+            { "doclet.help.serial_form.body", "\u6BCF\u4E2A\u53EF\u5E8F\u5217\u5316\u6216\u53EF\u5916\u90E8\u5316\u7684\u7C7B\u90FD\u6709\u5176\u5E8F\u5217\u5316\u5B57\u6BB5\u548C\u65B9\u6CD5\u7684\u8BF4\u660E\u3002\u6B64\u4FE1\u606F\u5BF9\u5B9E\u65BD\uFF08\u800C\u975E\u4F7F\u7528\uFF09API \u7684\u4EBA\u5458\u6709\u7528\u3002\u5C3D\u7BA1\u5BFC\u822A\u680F\u4E2D\u6CA1\u6709\u94FE\u63A5\uFF0C\u4F46\u60A8\u53EF\u4EE5\u901A\u8FC7\u4E0B\u5217\u65B9\u5F0F\u83B7\u53D6\u6B64\u4FE1\u606F\uFF1A\u8F6C\u81F3\u4EFB\u4F55\u5E8F\u5217\u5316\u7C7B\uFF0C\u7136\u540E\u5355\u51FB\u7C7B\u8BF4\u660E\u7684\u201C\u53E6\u8BF7\u53C2\u9605\u201D\u90E8\u5206\u4E2D\u7684\u201C\u5E8F\u5217\u5316\u5F62\u5F0F\u201D\u3002" },
             { "doclet.help.tree.head", "\u6811 (\u7C7B\u5206\u5C42\u7ED3\u6784)" },
             { "doclet.help.tree.intro", "\u5BF9\u4E8E\u6240\u6709\u7A0B\u5E8F\u5305\uFF0C\u90FD\u6709\u4E00\u4E2A {0} \u9875\uFF0C\u4EE5\u53CA\u6BCF\u4E2A\u7A0B\u5E8F\u5305\u7684\u5206\u5C42\u7ED3\u6784\u3002\u6BCF\u4E2A\u5206\u5C42\u7ED3\u6784\u9875\u90FD\u5305\u542B\u7C7B\u7684\u5217\u8868\u548C\u63A5\u53E3\u7684\u5217\u8868\u3002\u4ECE {1} \u5F00\u59CB\uFF0C\u6309\u7EE7\u627F\u7ED3\u6784\u5BF9\u7C7B\u8FDB\u884C\u6392\u5217\u3002\u63A5\u53E3\u4E0D\u4ECE {1} \u7EE7\u627F\u3002" },
             { "doclet.help.tree.overview", "\u67E5\u770B\u201C\u6982\u89C8\u201D\u9875\u9762\u65F6, \u5355\u51FB \"\u6811\" \u5C06\u663E\u793A\u6240\u6709\u7A0B\u5E8F\u5305\u7684\u5206\u5C42\u7ED3\u6784\u3002" },
@@ -170,6 +170,7 @@ public final class standard_zh_CN extends java.util.ListResourceBundle {
             { "doclet.navPackages", "\u7A0B\u5E8F\u5305" },
             { "doclet.navProperty", "\u5C5E\u6027" },
             { "doclet.navServices", "\u670D\u52A1" },
+            { "doclet.not.exhaustive", "\uFF08\u975E\u8BE6\u5C3D\uFF09" },
             { "doclet.package", "\u7A0B\u5E8F\u5305" },
             { "doclet.see.class_or_package_not_accessible", "\u6807\u8BB0{0}: \u65E0\u6CD5\u8BBF\u95EE\u5F15\u7528: {1}" },
             { "doclet.see.class_or_package_not_found", "\u6807\u8BB0{0}: \u627E\u4E0D\u5230\u5F15\u7528: {1}" },
