@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -192,7 +192,6 @@ public class CurrencyNames_ccp extends OpenListResourceBundle {
             { "SZL", "SZL" },
             { "THB", "\u0e3f" },
             { "TJS", "TJS" },
-            { "TMM", "TMM" },
             { "TMT", "TMT" },
             { "TND", "TND" },
             { "TOP", "TOP" },
@@ -359,8 +358,7 @@ public class CurrencyNames_ccp extends OpenListResourceBundle {
             { "mmk", "\ud804\udd1f\ud804\udd20\ud804\udd1a\ud804\udd34\ud804\udd1f\ud804\udd22\ud804\udd34 \ud804\udd07\ud804\udd28\ud804\udd20\ud804\udd16\ud804\udd34" },
             { "mnt", "\ud804\udd1f\ud804\udd27\ud804\udd0b\ud804\udd34\ud804\udd09\ud804\udd2e\ud804\udd23\ud804\udd28\ud804\udd20\ud804\udd1a\ud804\udd34 \ud804\udd16\ud804\udd2a\ud804\udd07\ud804\udd34\ud804\udd22\ud804\udd28\ud804\udd07\ud804\udd34" },
             { "mop", "\ud804\udd1f\ud804\udd33\ud804\udd20\ud804\udd07\ud804\udd33\ud804\udd20\ud804\udd03\ud804\udd2e \ud804\udd1b\ud804\udd11\ud804\udd07" },
-            { "mro", "\ud804\udd1f\ud804\udd2f\ud804\udd22\ud804\udd28\ud804\udd16\ud804\udd1a\ud804\udd28\ud804\udd20\ud804\udd1a\ud804\udd34 \ud804\udd03\ud804\udd2e\ud804\udd03\ud804\udd2a\ud804\udd09\ud804\udd2d\ud804\udd2a\ud804\udd20 (1973\u20132017)" },
-            { "mru", "\ud804\udd1f\ud804\udd2f\ud804\udd22\ud804\udd28\ud804\udd16\ud804\udd1a\ud804\udd28\ud804\udd20\ud804\udd1a\ud804\udd34 \ud804\udd03\ud804\udd2e\ud804\udd03\ud804\udd2a\ud804\udd09\ud804\udd2d\ud804\udd2a\ud804\udd20" },
+            { "mro", "\ud804\udd1f\ud804\udd2f\ud804\udd22\ud804\udd28\ud804\udd16\ud804\udd1a\ud804\udd28\ud804\udd20\ud804\udd1a\ud804\udd34 \ud804\udd03\ud804\udd2e\ud804\udd03\ud804\udd2a\ud804\udd09\ud804\udd2d\ud804\udd2a\ud804\udd20" },
             { "mtl", "\ud804\udd1f\ud804\udd23\ud804\udd34\ud804\udd11 \ud804\udd23\ud804\udd28\ud804\udd22" },
             { "mtp", "\ud804\udd1f\ud804\udd23\ud804\udd34\ud804\udd11 \ud804\udd1b\ud804\udd03\ud804\udd2a\ud804\udd1a\ud804\udd33\ud804\udd13\ud804\udd34" },
             { "mur", "\ud804\udd1f\ud804\udd2f\ud804\udd22\ud804\udd28\ud804\udd16\ud804\udd1a\ud804\udd28\ud804\udd20\ud804\udd1a\ud804\udd34 \ud804\udd22\ud804\udd2a\ud804\udd1b\ud804\udd28" },
@@ -417,8 +415,7 @@ public class CurrencyNames_ccp extends OpenListResourceBundle {
             { "srd", "\ud804\udd25\ud804\udd2a\ud804\udd22\ud804\udd28\ud804\udd1a\ud804\udd1f\ud804\udd34 \ud804\udd13\ud804\udd27\ud804\udd23\ud804\udd22\ud804\udd34" },
             { "srg", "\ud804\udd25\ud804\udd2a\ud804\udd22\ud804\udd28\ud804\udd1a\ud804\udd1f\ud804\udd34 \ud804\udd09\ud804\udd28\ud804\udd23\ud804\udd34\ud804\udd13\ud804\udd22\ud804\udd34" },
             { "ssp", "\ud804\udd18\ud804\udd27\ud804\udd09\ud804\udd28\ud804\udd1a\ud804\udd34 \ud804\udd25\ud804\udd2a\ud804\udd18\ud804\udd1a\ud804\udd28 \ud804\udd1b\ud804\udd03\ud804\udd2a\ud804\udd1a\ud804\udd33\ud804\udd13\ud804\udd34" },
-            { "std", "\ud804\udd25\ud804\udd03\ud804\udd2e \ud804\udd11\ud804\udd2e\ud804\udd1f\ud804\udd2c \ud804\udd03\ud804\udd33\ud804\udd03 \ud804\udd1b\ud804\udd33\ud804\udd22\ud804\udd28\ud804\udd1a\ud804\udd34\ud804\udd25\ud804\udd28\ud804\udd1b\ud804\udd2c \ud804\udd13\ud804\udd2e\ud804\udd1b\ud804\udd34\ud804\udd22 (1977\u20132017)" },
-            { "stn", "\ud804\udd25\ud804\udd03\ud804\udd2e \ud804\udd11\ud804\udd2e\ud804\udd1f\ud804\udd2c \ud804\udd03\ud804\udd33\ud804\udd03 \ud804\udd1b\ud804\udd33\ud804\udd22\ud804\udd28\ud804\udd1a\ud804\udd34\ud804\udd25\ud804\udd28\ud804\udd1b\ud804\udd2c \ud804\udd13\ud804\udd2e\ud804\udd1b\ud804\udd34\ud804\udd22" },
+            { "std", "\ud804\udd25\ud804\udd03\ud804\udd2e \ud804\udd11\ud804\udd2e\ud804\udd1f\ud804\udd2c \ud804\udd03\ud804\udd33\ud804\udd03 \ud804\udd1b\ud804\udd33\ud804\udd22\ud804\udd28\ud804\udd1a\ud804\udd34\ud804\udd25\ud804\udd28\ud804\udd1b\ud804\udd2c \ud804\udd13\ud804\udd2e\ud804\udd1b\ud804\udd34\ud804\udd22" },
             { "sur", "\ud804\udd25\ud804\udd2e\ud804\udd23\ud804\udd28\ud804\udd20\ud804\udd2c\ud804\udd16\ud804\udd34 \ud804\udd22\ud804\udd2a\ud804\udd1d\ud804\udd27\ud804\udd23\ud804\udd34" },
             { "svc", "\ud804\udd03\ud804\udd2c\ud804\udd23\ud804\udd34 \ud804\udd25\ud804\udd33\ud804\udd20\ud804\udd23\ud804\udd34\ud804\udd1e\ud804\udd2e\ud804\udd13\ud804\udd2e\ud804\udd22\ud804\udd34 \ud804\udd07\ud804\udd2e\ud804\udd23\ud804\udd2e\ud804\udd1a\ud804\udd34" },
             { "syp", "\ud804\udd25\ud804\udd28\ud804\udd22\ud804\udd28\ud804\udd20\ud804\udd1a\ud804\udd34 \ud804\udd1b\ud804\udd03\ud804\udd2a\ud804\udd1a\ud804\udd33\ud804\udd13\ud804\udd34" },
@@ -426,7 +423,7 @@ public class CurrencyNames_ccp extends OpenListResourceBundle {
             { "thb", "\ud804\udd17\ud804\udd2d \ud804\udd1d\ud804\udd16\ud804\udd34" },
             { "tjr", "\ud804\udd16\ud804\udd0e\ud804\udd28\ud804\udd07\ud804\udd28\ud804\udd0c\ud804\udd34\ud804\udd16\ud804\udd1a\ud804\udd34 \ud804\udd22\ud804\udd2a\ud804\udd1d\ud804\udd27\ud804\udd23\ud804\udd34" },
             { "tjs", "\ud804\udd16\ud804\udd0e\ud804\udd28\ud804\udd07\ud804\udd28\ud804\udd0c\ud804\udd34\ud804\udd16\ud804\udd1a\ud804\udd34 \ud804\udd25\ud804\udd2e\ud804\udd1f\ud804\udd2e\ud804\udd1a\ud804\udd28" },
-            { "tmm", "\ud804\udd16\ud804\udd2a\ud804\udd22\ud804\udd34\ud804\udd07\ud804\udd27\ud804\udd1f\ud804\udd2c\ud804\udd1a\ud804\udd28\ud804\udd0c\ud804\udd34\ud804\udd16\ud804\udd1a\ud804\udd28 \ud804\udd1f\ud804\udd1a\ud804\udd16\ud804\udd34(\ud804\udd37\ud804\udd3f\ud804\udd3f\ud804\udd39-\ud804\udd38\ud804\udd36\ud804\udd36\ud804\udd3f)" },
+            { "tmm", "\ud804\udd16\ud804\udd2a\ud804\udd22\ud804\udd34\ud804\udd07\ud804\udd27\ud804\udd1f\ud804\udd2c\ud804\udd1a\ud804\udd28\ud804\udd0c\ud804\udd34\ud804\udd16\ud804\udd1a\ud804\udd28 \ud804\udd1f\ud804\udd1a\ud804\udd16\ud804\udd34 (1993\u20132009)" },
             { "tmt", "\ud804\udd16\ud804\udd2a\ud804\udd22\ud804\udd34\ud804\udd07\ud804\udd27\ud804\udd1f\ud804\udd2c\ud804\udd1a\ud804\udd28\ud804\udd0c\ud804\udd34\ud804\udd16\ud804\udd1a\ud804\udd28 \ud804\udd1f\ud804\udd1a\ud804\udd16\ud804\udd34" },
             { "tnd", "\ud804\udd16\ud804\udd28\ud804\udd03\ud804\udd2a\ud804\udd1a\ud804\udd2c\ud804\udd25\ud804\udd28\ud804\udd20\ud804\udd1a\ud804\udd34 \ud804\udd18\ud804\udd28\ud804\udd1a\ud804\udd22\ud804\udd34" },
             { "top", "\ud804\udd11\ud804\udd2e\ud804\udd0b\ud804\udd34\ud804\udd09 \ud804\udd1b\ud804\udd33\ud804\udd03 \ud804\udd03\ud804\udd0b\ud804\udd34\ud804\udd09" },
@@ -472,8 +469,8 @@ public class CurrencyNames_ccp extends OpenListResourceBundle {
             { "zar", "\ud804\udd18\ud804\udd27\ud804\udd09\ud804\udd28\ud804\udd1a\ud804\udd34 \ud804\udd03\ud804\udd1c\ud804\udd33\ud804\udd22\ud804\udd28\ud804\udd07\ud804\udd1a\ud804\udd34 \ud804\udd22\ud804\udd33\ud804\udd20\ud804\udd1a\ud804\udd33\ud804\udd13\ud804\udd34" },
             { "zmk", "\ud804\udd0e\ud804\udd1f\ud804\udd34\ud804\udd1d\ud804\udd28\ud804\udd20\ud804\udd1a\ud804\udd34 \ud804\udd07\ud804\udd27\ud804\udd24\ud804\udd0c (\ud804\udd37\ud804\udd3f\ud804\udd3c\ud804\udd3e-\ud804\udd38\ud804\udd36\ud804\udd37\ud804\udd38)" },
             { "zmw", "\ud804\udd0e\ud804\udd1f\ud804\udd34\ud804\udd1d\ud804\udd28\ud804\udd20\ud804\udd1a\ud804\udd34 \ud804\udd07\ud804\udd27\ud804\udd24\ud804\udd0c" },
-            { "zrn", "\ud804\udd0e\ud804\udd2d\ud804\udd22\ud804\udd28\ud804\udd20\ud804\udd1a\ud804\udd34 \ud804\udd1a\ud804\udd28\ud804\udd05\ud804\udd2a \ud804\udd0e\ud804\udd2d\ud804\udd22\ud804\udd2c (\ud804\udd37\ud804\udd3f\ud804\udd3f\ud804\udd39-\ud804\udd37\ud804\udd3f\ud804\udd3f\ud804\udd3e)" },
-            { "zrz", "\ud804\udd0e\ud804\udd2d\ud804\udd22\ud804\udd28\ud804\udd20\ud804\udd1a\ud804\udd34 \ud804\udd1a\ud804\udd28\ud804\udd05\ud804\udd2a \ud804\udd0e\ud804\udd2d\ud804\udd22\ud804\udd2c (\ud804\udd37\ud804\udd3f\ud804\udd3d\ud804\udd37-\ud804\udd37\ud804\udd3f\ud804\udd3f\ud804\udd39)" },
+            { "zrn", "\ud804\udd0e\ud804\udd2d\ud804\udd22\ud804\udd28\ud804\udd20\ud804\udd1a\ud804\udd34 \ud804\udd1a\ud804\udd28\ud804\udd05\ud804\udd2a \ud804\udd0e\ud804\udd2d\ud804\udd22\ud804\udd2c (1993\u20131998)" },
+            { "zrz", "\ud804\udd0e\ud804\udd2d\ud804\udd22\ud804\udd28\ud804\udd20\ud804\udd1a\ud804\udd34 \ud804\udd1a\ud804\udd28\ud804\udd05\ud804\udd2a \ud804\udd0e\ud804\udd2d\ud804\udd22\ud804\udd2c (1971\u20131993)" },
             { "zwd", "\ud804\udd0e\ud804\udd28\ud804\udd1f\ud804\udd34\ud804\udd1d\ud804\udd1d\ud804\udd2a\ud804\udd20\ud804\udd2c \ud804\udd13\ud804\udd27\ud804\udd23\ud804\udd22\ud804\udd34 (\ud804\udd37\ud804\udd3f\ud804\udd3e\ud804\udd36-\ud804\udd38\ud804\udd36\ud804\udd36\ud804\udd3e)" },
             { "zwl", "\ud804\udd0e\ud804\udd28\ud804\udd1f\ud804\udd34\ud804\udd1d\ud804\udd1d\ud804\udd2a\ud804\udd20\ud804\udd2c \ud804\udd13\ud804\udd27\ud804\udd23\ud804\udd22\ud804\udd34 (\ud804\udd38\ud804\udd36\ud804\udd36\ud804\udd3f)" },
             { "zwr", "\ud804\udd0e\ud804\udd28\ud804\udd1f\ud804\udd34\ud804\udd1d\ud804\udd1d\ud804\udd2a\ud804\udd20\ud804\udd2c \ud804\udd13\ud804\udd27\ud804\udd23\ud804\udd22\ud804\udd34 (\ud804\udd38\ud804\udd36\ud804\udd36\ud804\udd3e)" },
