@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -103,7 +103,7 @@ public class CurrencyNames_ceb extends OpenListResourceBundle {
             { "chf", "Swiss Franc" },
             { "clp", "Chilean Peso" },
             { "cnh", "Chinese Yuan (layo sa baybayon)" },
-            { "cny", "Intsik nga Yuan" },
+            { "cny", "Chinese Yuan" },
             { "cop", "Colombian Peso" },
             { "crc", "Costa Rican Colon" },
             { "cuc", "Cuban Convertible Peso" },
@@ -120,7 +120,7 @@ public class CurrencyNames_ceb extends OpenListResourceBundle {
             { "eur", "Euro" },
             { "fjd", "Fijian Dollar" },
             { "fkp", "Falkland Islands Pound" },
-            { "gbp", "Inglatera nga Libra" },
+            { "gbp", "British Pound" },
             { "gel", "Georgian Lari" },
             { "ghs", "Ghanaian Cedi" },
             { "gip", "Gibraltar Pound" },
@@ -135,13 +135,13 @@ public class CurrencyNames_ceb extends OpenListResourceBundle {
             { "huf", "Hungarian Forint" },
             { "idr", "Indonesian Rupiah" },
             { "ils", "Israeli New Shekel" },
-            { "inr", "Rupee sa India" },
+            { "inr", "Indian Rupee" },
             { "iqd", "Iraqi Dinar" },
             { "irr", "Iranian Rial" },
             { "isk", "Icelandic Krona" },
             { "jmd", "Jamaican Dollar" },
             { "jod", "Jordanian Dinar" },
-            { "jpy", "Hapon nga Yen" },
+            { "jpy", "Japanese Yen" },
             { "kes", "Kenyan Shilling" },
             { "kgs", "Kyrgystani Som" },
             { "khr", "Cambodian Riel" },
@@ -187,7 +187,7 @@ public class CurrencyNames_ceb extends OpenListResourceBundle {
             { "qar", "Qatari Rial" },
             { "ron", "Romanian Leu" },
             { "rsd", "Serbian Dinar" },
-            { "rub", "Rusong ruble" },
+            { "rub", "Russian Ruble" },
             { "rwf", "Rwandan Franc" },
             { "sar", "Saudi Riyal" },
             { "sbd", "Solomon Islands Dollar" },
@@ -214,7 +214,7 @@ public class CurrencyNames_ceb extends OpenListResourceBundle {
             { "tzs", "Tanzanian Shilling" },
             { "uah", "Ukrainian Hryvnia" },
             { "ugx", "Ugandan Shilling" },
-            { "usd", "Dolyar sa US" },
+            { "usd", "US Dollar" },
             { "uyu", "Uruguayan Peso" },
             { "uzs", "Uzbekistani Som" },
             { "ves", "Venezuelan Bolivar" },
