@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -164,6 +164,7 @@ public class CurrencyNames_lt extends OpenListResourceBundle {
             { "MNT", "MNT" },
             { "MOP", "MOP" },
             { "MRO", "MRO" },
+            { "MRU", "MRU" },
             { "MUR", "MUR" },
             { "MVR", "MVR" },
             { "MWK", "MWK" },
@@ -219,6 +220,7 @@ public class CurrencyNames_lt extends OpenListResourceBundle {
             { "UYU", "UYU" },
             { "UZS", "UZS" },
             { "VEF", "VEF" },
+            { "VES", "VES" },
             { "VND", "VND" },
             { "VUV", "VUV" },
             { "WST", "WST" },
@@ -489,7 +491,8 @@ public class CurrencyNames_lt extends OpenListResourceBundle {
             { "uyu", "Urugvajaus pesas" },
             { "uzs", "Uzbekistano sumas" },
             { "veb", "Venesuelos bolivaras (1871\u20132008)" },
-            { "vef", "Venesuelos bolivaras" },
+            { "vef", "Venesuelos bolivaras (2008\u20132018)" },
+            { "ves", "Venesuelos bolivaras" },
             { "vnd", "Vietnamo dongas" },
             { "vnn", "Vietnamo dongas (1978\u20131985)" },
             { "vuv", "Vanuatu vatas" },
