@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -202,6 +202,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "%%CREISS", "Creiss" },
             { "type.nu.hebr", "Hebreeuwse cijfers" },
             { "CA", "Canada" },
+            { "Kits", "Kitaans kleinschrift" },
             { "CC", "Cocoseilanden" },
             { "mzn", "Mazanderani" },
             { "CD", "Congo-Kinshasa" },
@@ -225,6 +226,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "type.nu.bali", "Balinese cijfers" },
             { "CZ", "Tsjechi\u00eb" },
             { "eka", "Ekajuk" },
+            { "Ahom", "Ahom" },
             { "Pauc", "Pau Cin Hau" },
             { "vls", "West-Vlaams" },
             { "%%RIGIK", "Klassiek Volap\u00fck" },
@@ -476,6 +478,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "MQ", "Martinique" },
             { "MR", "Mauritani\u00eb" },
             { "MS", "Montserrat" },
+            { "Chrs", "Chorasmisch" },
             { "MT", "Malta" },
             { "cps", "Capiznon" },
             { "type.m0.ungegn", "UNGEGN" },
@@ -646,6 +649,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "TC", "Turks- en Caicoseilanden" },
             { "yav", "Yangben" },
             { "TD", "Tsjaad" },
+            { "Qaag", "Zawgyi" },
             { "TF", "Franse Gebieden in de zuidelijke Indische Oceaan" },
             { "ase", "Amerikaanse Gebarentaal" },
             { "TG", "Togo" },
@@ -825,6 +829,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "sba", "Ngambay" },
             { "Guru", "Gurmukhi" },
             { "%%ALUKU", "Aloekoe-dialect" },
+            { "type.nu.diak", "Dives Akuru cijfers" },
             { "lua", "Luba-Lulua" },
             { "%%BISCAYAN", "Biskajaans" },
             { "type.nu.tirh", "Tirhuta cijfers" },
@@ -858,6 +863,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "scn", "Siciliaans" },
             { "aa", "Afar" },
             { "ab", "Abchazisch" },
+            { "Aran", "Nastaliq" },
             { "bbc", "Batak Toba" },
             { "ae", "Avestisch" },
             { "af", "Afrikaans" },
@@ -950,7 +956,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "type.co.big5han", "Traditioneel-Chinese sorteervolgorde - Big5" },
             { "es", "Spaans" },
             { "et", "Estisch" },
-            { "Hanb", "Hanb" },
+            { "Hanb", "Han met Bopomofo" },
             { "eu", "Baskisch" },
             { "Buhd", "Buhid" },
             { "Hang", "Hangul" },
@@ -1143,6 +1149,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "kaw", "Kawi" },
             { "dtp", "Dusun" },
             { "or", metaValue_or },
+            { "Modi", "Modi" },
             { "os", "Ossetisch" },
             { "%%ALALC97", "Romanisering ALA-LC, editie 1997" },
             { "bpy", "Bishnupriya" },
@@ -1377,6 +1384,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "%%LENGADOC", "Lengadoc" },
             { "kmb", "Kimbundu" },
             { "type.nu.jpanfin", "Japanse financi\u00eble cijfers" },
+            { "Cham", "Cham" },
             { "gez", "Ge\u2019ez" },
             { "mrj", "West-Mari" },
             { "Syrn", "Oost-Aramees" },
@@ -1388,6 +1396,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "Tglg", metaValue_tl },
             { "Egyd", "Egyptisch demotisch" },
             { "Egyh", "Egyptisch hi\u00ebratisch" },
+            { "Yezi", "Jezidi" },
             { "%%ITIHASA", "Episch Sanskriet" },
             { "Palm", "Palmyreens" },
             { "ebu", "Embu" },
@@ -1412,10 +1421,12 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "ilo", "Iloko" },
             { "%%VALENCIA", "Valenciaans" },
             { "Cprt", "Cyprisch" },
+            { "Diak", "Dives Akuru" },
             { "%%BAKU1926", "Eenvormig Turkse Latijnse alfabet" },
             { "%%IJEKAVSK", "Servisch met Ijekaviaanse uitspraak" },
             { "mua", "Mundang" },
             { "type.nu.guru", "Gurmukhi cijfers" },
+            { "%%BORNHOLM", "Bornholms" },
             { "mul", "Meerdere talen" },
             { "%%PUTER", "Puter" },
             { "cad", "Caddo" },
@@ -1432,6 +1443,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "inh", "Ingoesjetisch" },
             { "krj", "Kinaray-a" },
             { "kri", "Krio" },
+            { "fa_AF", "Dari" },
             { "krl", "Karelisch" },
             { "%%OXENDICT", "Spelling volgens het Oxford English Dictionary" },
             { "efi", "Efik" },
